% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/directory_search.r
\name{keyword_directory}
\alias{keyword_directory}
\title{Wrapper for keyword search function}
\usage{
keyword_directory(directory, keyword, split_pdf = FALSE,
  surround_lines = FALSE, ignore_case = FALSE, full_names = FALSE,
  recursive = FALSE, max_search = NULL)
}
\arguments{
\item{directory}{The directory to perform the search for pdf files to search.}

\item{keyword}{The keyword(s) to be used to search in the text. Multiple 
keywords can be specified with a character vector.}

\item{split_pdf}{TRUE/FALSE indicating whether to split the pdf using white 
space. This would be most useful with multicolumn pdf files. 
The split_pdf function attempts to recreate the column layout of the text 
into a single column starting with the left column and proceeding to the 
right.}

\item{surround_lines}{numeric/FALSE indicating whether the output should 
extract the surrouding lines of text in addition to the matching line. 
Default is FALSE, if not false, include a numeric number that indicates 
the additional number of surrounding lines that will be extracted.}

\item{ignore_case}{TRUE/FALSE/vector of TRUE/FALSE, indicating whether the 
case of the keyword matters. 
Default is FALSE meaning that case of the keyword is literal. If a vector, 
must be same length as the keyword vector.}

\item{full_names}{TRUE/FALSE indicating if the full file path should be used.
Default is FALSE, see \code{\link{list.files}} for more details.}

\item{recursive}{TRUE/FALSE indicating if subdirectories should be searched 
as well.
Default is FALSE, see \code{\link{list.files}} for more details.}

\item{max_search}{An optional numeric vector indicating the maximum number
of pdfs to search. Will only search the first n cases.}
}
\description{
This will use the keyword_search function to loop over all pdf files in a 
directory. Includes the ability to include subdirectories as well.
}
\examples{
# find directory
directory <- system.file('pdf', package = 'pdfsearch')

# do search over two files
keyword_directory(directory, 
       keyword = c('repeated measures', 'measurement error'),
       surround_lines = 1, full_names = TRUE)
       
# can also split pdfs
keyword_directory(directory, 
       keyword = c('repeated measures', 'measurement error'),
       split_pdf = TRUE,
       surround_lines = 1, full_names = TRUE)


}

